
<?php
/*
 *  Copyright 2003-2033 dahantc.com Inc.All Rights Reserved.
 *
 */

class VoiceReportSDK {
	private $accountSid; //帐号ID
	private $authToken;	 //授权令牌
	private $apiUrl; //API请求路径
	private $smsUrl = "{apiUrl}/voice/report"; //短信API路径
	private $logFile = "log.txt"; // 日志文件
	private $logOn = true; // true：开启日志， false：关闭日志，默认开启
	private $logHandle; //log文件句柄
	private $timeStamp; //时间戳
	
	function __construct() {
		$this->logHandle = fopen($this->logFile, 'a');
		$this->timeStamp = date("YmdHis");
	}
    
    public function setAccountSid($accountSid) {
      	$this->accountSid = $accountSid; 
    }
    
    public function setAuthToken($authToken) {
      	$this->authToken = $authToken;   
    }
    
    public function setApiUrl($apiUrl) {
      	$this->apiUrl = $apiUrl;   
    }
    
    // 开启或关闭日志
    public function setLogOn($logOn) {
    	$this->logOn = $logOn;
    }
    
    private function log($log) {
      	if(!$this->logOn) return;
     	fwrite($this->logHandle, $log."\n");
    }
    
    private function checkConfig() {    
        if($this->accountSid == ""){
          	return $this->getStatusData('000017', 'AccountSid为空');
        }
        
        if($this->authToken == ""){
          	return $this->getStatusData('000018', 'Auth Token为空');
        }
        
        if($this->apiUrl == ""){
          	return $this->getStatusData('000019', 'API URL为空');
        }
        
        return "";
    }
    
    private function getStatusData($code, $msg) {
    	 $data = new stdClass();
         $data->statusCode = $code;
         $data->statusMsg = $msg;
         
         return $data;
    }
    
    private function buildRequestUrl() {
        $url = str_replace("{apiUrl}", $this->apiUrl, $this->smsUrl);
        
        return $url;
    }

    private function buildRequestHeader() {
        $auth = base64_encode($this->accountSid . ":" . $this->timeStamp);
        $sig = strtoupper(md5($this->accountSid . $this->authToken . $this->timeStamp));
        $header = array("Accept:application/json",
        				"Content-Type:application/json;charset=utf-8",
        				"sig:$sig",
        				"Authorization:$auth");
        				
        return $header;
    }
   	
   	// HTTP POST请求
    private function http_post($url, $header) {
       $ci = curl_init();

       curl_setopt($ci, CURLOPT_SSL_VERIFYHOST, false);
       curl_setopt($ci, CURLOPT_SSL_VERIFYPEER, false);
       curl_setopt($ci, CURLOPT_HEADER, false);
       curl_setopt($ci, CURLOPT_POST, true);
       curl_setopt($ci, CURLOPT_RETURNTRANSFER, true);
       curl_setopt($ci, CURLOPT_URL, $url);
       curl_setopt($ci, CURLOPT_HTTPHEADER, $header);
       $result = curl_exec($ci);
       
       if($result == NULL) {
          echo "http request error  <br/>"; 
          $result = "{\"code\":\"000010\", \"msg\":\"服务器请求出错，请确认参数是否正确，如无法解决，请联系工作人员\"}";
       }

       curl_close($ci);
       return $result;
     }
     
    /**
    * 获取短信状态报告
    */
    public function getVoiceReport() {
        // 检查配置参数
        $config = $this->checkConfig();
        if($config != "") return $config;
        
        // 生成请求参数
        $url = $this->buildRequestUrl();
        $header = $this->buildRequestHeader();
        $this->log("--- Start to get Voice Report ---");
        $this->log("url: $url");
        $this->log("header: " . implode(' ', $header));

        // 调用平台短信接口
        $result = $this->http_post($url, $header);
		$this->log("response result: " . $result);
		//echo "response result: $result <br/>";
		
        return json_decode($result);
    }
	
}
?>
